//  ACLMorphRequest
//
//  This class extends the standard DXRequest class to carry additional information needed by the
//  DbACLMorph processing exit and the AppTransactionHandler.
//
//  Message Identifier:      N/A
//  Message Range:           0000 - 0000
//  Trace area assignment:   None
//  Version:                 1.0.3  Build: 38
//
//  Version History:
//
//  1.0.0		14/10/2010		Base Release
//  1.0.3		22/10/2011		VS 2011 Updates
//
//  Copyright: Hadleigh Marshall (Netherlands) b.v. 2010 - 2011
//

//  Application Includes
#include "ACLMorphRequest.h"

//  Constructor
ACLMorphRequest::ACLMorphRequest()
{
	nidTX = 0;
	acrTransform = NULL;
	hTXLog = NULLHANDLE;
	TransID[0] = '\0';
	dwDbsUpdated = 0;
}

//  Destructor
ACLMorphRequest::~ACLMorphRequest()
{
}

//  InheritFrom
//
//  This function will populate the basic members of the current request from a passed request
//  Also populating the items in the extended request
//
//  Parameters
//  1  -  DXRequest *		-  Pointer to a DXRequest object that defines the eXplorer search scope and constraints
//
//  Returns
//
//  API Use Notes:
//
//
void ACLMorphRequest::InheritFrom(DXRequest *dxrParent)
{
	ACLMorphRequest			*amrParent;							//  Parent Acl Morph Request

	//  Cast the passed request 
	amrParent = (ACLMorphRequest *) dxrParent;

	//  Copy the specific items from the parent
	nidTX = amrParent->nidTX;
	acrTransform = amrParent->acrTransform;
	hTXLog = amrParent->hTXLog;
	strcpy_s(TransID, MAX_DATABASE, amrParent->TransID);
	return BaseInheritFrom(dxrParent);
}

//  CreateNewInstance
//
//  This function will create a new DXRequest instance and return it to the caller. 
//  This function can be overridden in extending classes, to allow extending classes to be handled by
//  the DX core functions.
//
//  Parameters
//
//  Returns
//
//  API Use Notes:
//
//
DXRequest * ACLMorphRequest::CreateNewInstance(void)
{
	return new ACLMorphRequest();	
}

//  PromoteScores
//
//  This function will accumulate the scanning scores from this request into a higher level request
//
//  Parameters
//  1  -  DXRequest *		-  Pointer to a DXRequest object that defines the eXplorer search scope and constraints
//
//  Returns
//
//  API Use Notes:
//
//  In any replacement invoke the BasePromoteScores() protected method to perform existing promotion
//
void ACLMorphRequest::PromoteScores(DXRequest *dxrParent)
{
	ACLMorphRequest			*amrParent;							//  Parent ACL Morph Request

	//  Cast the passed request 
	amrParent = (ACLMorphRequest *) dxrParent;

	amrParent->dwDbsUpdated = amrParent->dwDbsUpdated + dwDbsUpdated;
	return BasePromoteScores(dxrParent);
}
