#pragma once
//  AppCommandHandler
//
//  This class provides the custom MQ command handling for the QACLMorph application
//
//  Message Identifier:      QAM
//  Message Range:           0200 - 0299
//  Trace area assignment:   None
//  Version:                 1.0.3  Build: 38
//
//  Version History:
//
//  1.0.0		14/10/2010		Base Release
//  1.0.3		22/10/2011		VS 2011 Updates
//
//  Copyright: Hadleigh Marshall (Netherlands) b.v. 2010 - 2011
//

//  Application Includes
#include "../DXCommon/MTX/CommandHandler.h"
#include "../DXCommon/MTX/TransactionQueue.h"

//  Custom Tell (MQ) Command strings
#define		MQ_CMD_STRING_MAXTRANS		"MAXTRANS"

//  Encoded Custom Tell (MQ) commands
#define		MQ_COMMAND_MAXTRANS				MQ_COMMAND_USER+1

//  Information Messages
#define		MSG_QAM0201I			"QAM0201I: %i transaction have been dispatched, %i completed, %i are running, max concurrency is %i."
#define		MSG_QAM0203I			"QAM0203I: Transaction processing has been suspended on queue '%s'."
#define		MSG_QAM0204I			"QAM0204I: Transaction processing has been resumed on queue '%s'."
#define		MSG_QAM0205I			"QAM0205I: Transaction processing is suspended on queue '%s'."
#define		MSG_QAM0207I			"QAM0207I: Maximum Concurrent Transactions on queue '%s' has been changed from %i to %i."

//  Error Messages
#define		MSG_QAM0202E			"QAM0202E: No transaction queue is currently active for this processor."
#define		MSG_QAM0206E			"QAM0206E: Invalid setting for Max Concurrent Transactions on queue '%s' has been ignored."

//  Miscellaneous Definitions
#define		ADDIN_STATUS_RUNNING		"Running"
#define		ADDIN_STATUS_SUSPENDED		"Suspended"

class AppCommandHandler :
	public CommandHandler
{
public:
	//  Default constructor
	AppCommandHandler(void);

	//  Normal Constructor
	AppCommandHandler(ExecEnvironment *xeParent);

	//  Destructor
	~AppCommandHandler(void);

	//  Public Members
	TransactionQueue			*tqCurrent;							//  Pointer to transaction Queue

protected:
	//  Protected Members

	//  Protected Functions
	WORD	virtual ParseCustomCommand(char *szCommand, char *szOptions, int iThreadID);	//  Parse a Custom Command
	WORD	virtual CustomCommandHandler(WORD wCommand, char *szOptions, int iThreadID);	//  Process Custom Commands
};
