#pragma once
//  AppRunSettings
//
//  This class provides the Application Execution settings for the QACLMorph application
//
//  Message Identifier:      QAM
//  Message Range:           0001 - 0099
//  Trace area assignment:   None
//  Version:                 1.0.3  Build: 38
//
//  Version History:
//
//  1.0.0		11/10/2010		Initial Version
//  1.0.3		22/10/2011		VS 2011 Updates
//
//  Copyright: Hadleigh Marshall (Netherlands) b.v. 2010
//
#include "../DXCommon/RunSettings.h"

//  Error Messages
#define		MSG_QAM0001E			"QAM0001E: Too few parameters supplied."
#define		MSG_QAM0002E			"QAM0002E: Invalid program switch '%s' has been ignored."
#define		MSG_QAM0003E			"QAM0003E: Invalid program parameter '%s' has been ignored."
#define		MSG_QAM0004E			"QAM0004E: Invalid thread count %i supplied, program will not run."

//  Information Messages
#define		MSG_QAM0005I			"QAM0005I: Control database is '%s'."
#define		MSG_QAM0006I			"QAM0006I: Current logging level is: %s."
#define		MSG_QAM0007I			"QAM0007I: QACLMorph will use %i threads."

//  Unnumbered messages
#define		MSG_USAGE1				"Usage:"
#define		MSG_USAGE2				"QACLMorph ControlDb [-V][-T[:nn]][-D][-E][-M:nn][-X:nn]"
#define		MSG_USAGE3				"  ControlDb - Control database (relative to the Notes data directory)."
#define		MSG_USAGE4				"  [-V]|[-T[:area]]|[-D] - Set logging level to Verbose, Trace or Debug."
#define		MSG_USAGE5				"  [-M:nn] - Number of threads to use."
#define		MSG_USAGE6				"  [-X:nn] - Max number of concurrent transactions."
#define		MSG_USAGE7				"  [-E] - Echo messages to the server console."
#define		MSG_USAGE8				"Copyright: Hadleigh Marshall Netherlands 2010."

//  Local Definitions
#define		MIN_THREADCOUNT			10								//  Minimum allowable threads
#define		MAX_THREADCOUNT			200								//  Maximum allowable threads
#define		DEFAULT_THREADCOUNT		10								//  Default 10 threads for execution
#define		DEFAULT_TXCOUNT			1								//  Default max 1 concurrent transaction

//  Class Definition
class AppRunSettings :
	public RunSettings
{
public:
	//  Constructor
	AppRunSettings(int argc, char * argv[]);

	//  Destructor
	~AppRunSettings(void);

	//  Public Members
	int		ThreadCount;											//  Number of threads to use
	int		MaxCTX;													//  Max Concurrent transactions
private:
	//  Private Functions
	BOOL SetDefaults(void);											//  Set the application run defaults
	BOOL ValidateParameters(int argc, char * argv[]);				//  Validate Parameters
	void ShowUsage(void);											//  Show program usage
	void ShowSettings(void);										//  Show the current settings
	BOOL ParseRequestScope(char * szScope1, char * szScope2);		//  Parse the request scope};

};
