#pragma once
//  AppTransactionHandler
//
//  This class provides the custom Transaction Queue handling for the QACLMorph application
//
//  Message Identifier:      QAM
//  Message Range:           0300 - 0399
//  Trace area assignment:   None
//  Version:                 1.0.3  Build: 38
//
//  Version History:
//
//  1.0.0		14/10/2010		Base Release
//  1.0.3		22/10/2011		VS 2011 Updates
//
//  Copyright: Hadleigh Marshall (Netherlands) b.v. 2010 - 2011
//

//  Runtime Includes
#include "../DXCommon/MTX/TransactionHandler.h"						//  Transaction Queue Handler
#include "../DXCommon/MTDX/DominoExplorer.h"						//  Domino Explorer
#include "../DXCommon/ACL/DXACLRuleSetParser.h"						//  DX ACL Rule Set Parser

//  Application Includes
#include "ACLMorphRequest.h"										//  ACL Morph Request
#include "DbACLMorpher.h"											//  Processing Exit

//  Items on an ACLMorphRequest transaction
#define 	ITEM_TRANSID			"TransReqID"
#define		ITEM_SERVER				"TargetServer"
#define		ITEM_DATABASE			"TargetDatabase"
#define		ITEM_ACLPATT			"ACLPattern"
#define		ITEM_ALLOWRECURSION		"AllowRecursion"
#define		TRANSDOC_HISTORY		"History"
#define		ITEM_STATS_SERVERS		"ServersProcessed"
#define		ITEM_STATS_DIRS			"DirectoriesProcessed"
#define		ITEM_STATS_DBS			"DatabasesScanned"
#define		ITEM_STATS_ACLS			"DatabaseACLsUpdated"
#define		ITEM_STATS_ELAPSED		"ElapsedTime"
#define		ITEM_START_UPDATE		"UpdateStarted"

//  Miscellaneous Definitions
#define		LOG_TRUNCATED_MSG		"....Transaction Log Truncated ......."

//  Information Messages
#define		MSG_QAM0305I		"QAM0305I: Transaction ID: '%s' in Queue '%s' has completed and updated %i database ACLs out of %i examined."

//  Error Messages
#define		MSG_QAM0301E		"QAM0301E: Transaction '%s' does not contain an ACL Specification, transaction rejected."
#define		MSG_QAM0302E		"QAM0302E: Transaction '%s' does not contain a valid scope definition, transaction rejected."
#define		MSG_QAM0303E		"QAM0303E: Transaction '%s' contains an ACL Specification that was not valid, transaction rejected."
#define		MSG_QAM0304E		"QAM0304E: Unable to open transaction ID: '%s' (Note ID: 0x%.4X) in Queue '%s', status has not been updated."
#define		MSG_QAM0306E		"QAM0306E: Unable to allocate a list for the transaction history log, continuing without one."
#define		MSG_QAM0307E		"QAM0307E: Unable to add a line to the transaction history log, the log is truncated."
#define		MSG_QAM0308E		"QAM0308E: Unable to add the transaction history log to the transaction document."
#define		MSG_QAM0309E		"QAM0309E: Unable to remove the old transaction history log from a document."

//  Class Definition
class AppTransactionHandler :
	public TransactionHandler
{
public:
	//  Default constructor
	AppTransactionHandler(void);

	//  Normal Constructor
	AppTransactionHandler(MTExecutive *xeParent, int iThreadID);

	//  Destructor
	~AppTransactionHandler(void);

	//  Public Members
	DominoExplorer			*dxTarget;											//  Domino Explorer - this is the executor
	DbACLMorpher			*amReporter;										//  DbACLMorpher - is set as the exit in all requests
	DXACLRuleSetParser		*rsParser;											//  The ACL Rule Set Parser

private:
	//  Private Members

	//  Private Functions
	void LogTransactionMessage(char *szMsg, HANDLE hTXLog, int iThreadID);		//  Log a transaction message
	void AddHistory(HANDLE hTXLog, NOTEHANDLE hnTX, int iThreadID);				//  Add history to transaction document

protected:
	//  Protected Members

	//  Protected Functions
	void virtual SerializeTransaction(void *txObject, DBHANDLE hdbQueue, TransactionQueue *tqCurrent, int iThreadID);
	int virtual MarshallTransaction(NOTEID nidTX, NOTEHANDLE hnTX, TransactionQueue *tqCurrent, void **txObject, void **xxObject, UINT *Attrs, int *Priority, int iThreadID);
};

