#pragma once
//  DbACLMorpher
//
//  This class is an extension of the DXReporter class that provides a per database invocation
//  of the ACL coersion provided by the ACL handling objects.
//
//  Version:  1.0.3
//  Build:    38
//
//  Copyright: Hadleigh Marshall (Netherlands) b.v. 2010 - 2011
//

//  Runtime Includes
#include "../DXCommon/MTX/MTExecutive.h"
#include "../DXCommon/MTDX/DXReporter.h"
#include "../DXCommon/ACL/DXACLRuleSet.h"

//  Application Includes
#include "ACLMorphRequest.h"

//  Miscellaneous Definitions
#define		LOG_TRUNCATED_MSG		"....Transaction Log Truncated ......."
#define		HISTORY_MUTEX			APP_MUTEX_1			//  Define the history Mutex

//  Trace Messages
#define		MSG_QAM0409T		"QAM0409T: DbACLMorpher entered for Request: %p in Thread: %i."
#define		MSG_QAM0410T		"QAM0410T: Starting clone of RuleSet: %p into new RuleSet: %p."

//  Information Messages
#define		MSG_QAM0402I		"QAM0402I: Skipping updates to the current ACL because the -S(kip) option is in effect." 
#define		MSG_QAM0403I		"QAM0403I: The ACL has been updated in '%s\\%s' on '%s'."

//  Error Messages
#define		MSG_QAM0404E		"QAM0404E: Failed to get the ACL for the target database '%s\\%s' on '%s'."
#define		MSG_QAM0405E		"QAM0405E: Failed to update the ACL for the target database '%s\\%s' on '%s'."
#define		MSG_QAM0406E		"QAM0406E: No cloned ACL Rule Set is available to process database '%s\\%s' on '%s'."
#define		MSG_QAM0407E		"QAM0407E: Unable to add a line to the transaction history log, the log is truncated."
#define		MSG_QAM0408E		"QAM0408E: Panic induced with Runtime: %p and Request: %p in Thread: %i."

//  Local Definitions
#define		REPORTER_DESC			"Database ACL Morpher"

//  Class Definition
class DbACLMorpher :
	public DXReporter
{
public:
	//  Default Constructor
	DbACLMorpher(void);

	//  Normal constructor taking the DX Runtime
	DbACLMorpher(MTExecutive *xeParent, int iThreadID);

	//  Destructor
	~DbACLMorpher(void);

	//  Public Members
	//  Public Functions
	virtual BOOL ReportOnThisDb(DXRequest *dxrRQ, DBHANDLE hdbEntity, int iThreadID);			//  Report on the selected Db
	virtual void GetDescription(char *szDescription);											//  Return the description of this reporter

private:
	//  Private Members

	//  Private Functions
	void LogTransactionMessage(char *szMsg, HANDLE hTXLog, int iThreadID);						//  Log a transaction message

protected:
	//  Protexted Members
	MTExecutive			*xeLocal;						//  Current Runtime
};
